"use strict";

try {
  const HtmlWebPackPlugin = require("html-webpack-plugin");
  const { CleanWebpackPlugin } = require("clean-webpack-plugin");
  const MiniCssExtractPlugin = require("mini-css-extract-plugin");

  module.exports = {
    entry: {
      main: ["@babel/polyfill", `${process.cwd()}/src/index.js`],
    },
    output: {
      globalObject: "this",
      path: `${process.cwd()}/app/scripts`,
      filename: "[name].[contenthash:8].js",
      chunkFilename: "[name].[contenthash:8].js",
      publicPath: "./scripts",
    },
    devtool: "source-map",
    module: {
      rules: [
        {
          test: /\.(js|jsx|ts|tsx|test.js)$/,
          exclude: /node_modules/,
          use: {
            loader: "babel-loader",
          },
        },
        {
          test: /\.(css|scss)$/,
          use: ["style-loader", "css-loader"],
        },
        {
          test: /\.(png|jpe?g|gif|svg)$/i,
          use: [
            {
              loader: "file-loader",
              options: {
                name: "[name][contenthash:8].[ext]",
                outputPath: "/assets/img",
                esModule: false,
              },
            },
          ],
        },
        {
          test: /\.(woff|woff2|ttf|eot)$/i,
          include: /node_modules/,
          use: [
            {
              loader: "file-loader",
              options: {
                name: "[name].[ext]",
              },
            },
          ],
        },
      ],
    },
    plugins: [
      new CleanWebpackPlugin({
        dangerouslyAllowCleanPatternsOutsideProject: true,
        dry: false,
      }),
      new MiniCssExtractPlugin({
        filename: "[name].[contenthash:8].css",
        chunkFilename: "[name].[contenthash:8].css",
      }),
      new HtmlWebPackPlugin({
        template: `${process.cwd()}/public/index.html`,
        filename: `${process.cwd()}/app/index.html`,
      }),
    ],
    optimization: {
      moduleIds: "deterministic",
      runtimeChunk: "single",
      splitChunks: {
        cacheGroups: {
          vendor: {
            test: /[\\/]node_modules[\\/]/,
            name: "vendors",
            priority: -10,
            chunks: "all",
          },
        },
      },
    },
  };
} catch {
  console.log("Failed");
}
